package com.twelvet.server.system.mapper;

import com.twelvet.api.system.domain.SysDictType;

import java.util.List;

/**
 * @author twelvet
 * @WebSite twelvet.cn
 * @Description: 字典表 数据层
 */
public interface SysDictTypeMapper {

	/**
	 * 根据条件分页查询字典类型
	 * @param dictType 字典类型信息
	 * @return 字典类型集合信息
	 */
	List<SysDictType> selectDictTypeList(SysDictType dictType);

	/**
	 * 根据所有字典类型
	 * @return 字典类型集合信息
	 */
	List<SysDictType> selectDictTypeAll();

	/**
	 * 根据字典类型ID查询信息
	 * @param dictId 字典类型ID
	 * @return 字典类型
	 */
	SysDictType selectDictTypeById(Long dictId);

	/**
	 * 根据字典类型查询信息
	 * @param dictType 字典类型
	 * @return 字典类型
	 */
	SysDictType selectDictTypeByType(String dictType);

	/**
	 * 通过字典ID删除字典信息
	 * @param dictId 字典ID
	 * @return 结果
	 */
	int deleteDictTypeById(Long dictId);

	/**
	 * 批量删除字典类型信息
	 * @param dictIds 需要删除的字典ID
	 * @return 结果
	 */
	int deleteDictTypeByIds(Long[] dictIds);

	/**
	 * 新增字典类型信息
	 * @param dictType 字典类型信息
	 * @return 结果
	 */
	int insertDictType(SysDictType dictType);

	/**
	 * 修改字典类型信息
	 * @param dictType 字典类型信息
	 * @return 结果
	 */
	int updateDictType(SysDictType dictType);

	/**
	 * 校验字典类型称是否唯一
	 * @param dictType 字典类型
	 * @return 结果
	 */
	SysDictType checkDictTypeUnique(String dictType);

}
